@@ -605,6 +605,58 @@ evdev_is_wellspring3(unsigned short *id)
   return 0;
 }
 
+/* MacBookAir3,2 (October 2010) */
+static int
+evdev_is_wellspring4(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_WELLSPRING4_ANSI)
+      || (product == USB_PRODUCT_ID_WELLSPRING4_ISO)
+      || (product == USB_PRODUCT_ID_WELLSPRING4_JIS))
+    {
+      logdebug(" -> WellSpring IV USB assembly\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
+/* MacBookAir3,1 (October 2010) */
+static int
+evdev_is_wellspring4a(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_WELLSPRING4A_ANSI)
+      || (product == USB_PRODUCT_ID_WELLSPRING4A_ISO)
+      || (product == USB_PRODUCT_ID_WELLSPRING4A_JIS))
+    {
+      logdebug(" -> WellSpring IVa USB assembly\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
 /* Any internal keyboard */
 static int
 evdev_is_internal(unsigned short *id)
@@ -614,7 +666,9 @@ evdev_is_internal(unsigned short *id)
 	  || evdev_is_geyser4hf(id)
 	  || evdev_is_wellspring(id)
 	  || evdev_is_wellspring2(id)
-	  || evdev_is_wellspring3(id));
+	  || evdev_is_wellspring3(id)
+	  || evdev_is_wellspring4(id)
+	  || evdev_is_wellspring4a(id));
 }
 
 
