@@ -379,9 +379,6 @@ kbd_backlight_fix_config(void)
 
   if (kbd_cfg.step > (KBD_BACKLIGHT_MAX / 2))
     kbd_cfg.step = KBD_BACKLIGHT_MAX / 2;
-
-  if (kbd_cfg.idle > 0)
-    kbd_cfg.idle = (kbd_cfg.idle * 1000) / KBD_TIMEOUT;
 }
 
 
@@ -407,10 +404,20 @@ kbd_get_i2cdev(void)
 	}
 
       fp = fopen(buf, "r");
-      if ((fp == NULL) && (errno != ENOENT))
+      if (fp == NULL)
 	{
-	  logmsg(LOG_ERR, "Error: i2c device probe: cannot open %s: %s", buf, strerror(errno));
-	  continue;
+	  if (errno != ENOENT)
+	    {
+	      logmsg(LOG_ERR, "Error: i2c device probe: cannot open %s: %s", buf, strerror(errno));
+	      continue;
+	    }
+	  else
+	    {
+	      logmsg(LOG_ERR, "Error: i2c device probe: i2c device not found, is i2c-dev loaded?");
+
+	      i2c_bus = 256;
+	      break;
+	    }
 	}
 
       ret = fread(buf, 1, PATH_MAX - 1, fp);
