@@ -287,6 +287,23 @@ struct machine_ops mb_mops[] = {
     /* .evdev_identify = evdev_is_wellspring3, */
   },
 
+  {  /* MacBookPro6,1 (17", Core i5/i7, April 2010)
+      * MacBookPro6,2 (15", Core i5/i7, April 2010) */
+    .type = MACHINE_MACBOOKPRO_6,
+    .lcd_backlight_probe = mbp_sysfs_backlight_probe,
+    .lcd_backlight_step = sysfs_backlight_step,
+    .lcd_backlight_toggle = sysfs_backlight_toggle,
+    /* .evdev_identify = evdev_is_wellspring3, */
+  },
+
+  {  /* MacBookPro7,1 (13", Core2 Duo, April 2010) */
+    .type = MACHINE_MACBOOKPRO_7,
+    .lcd_backlight_probe = mbp_sysfs_backlight_probe,
+    .lcd_backlight_step = sysfs_backlight_step,
+    .lcd_backlight_toggle = sysfs_backlight_toggle,
+    /* .evdev_identify = evdev_is_wellspring3, */
+  },
+
   /* MacBook machines */
 
   {  /* MacBook1,1 (Core Duo) */
@@ -329,6 +346,14 @@ struct machine_ops mb_mops[] = {
     /* .evdev_identify = evdev_is_wellspring3, */
   },
 
+  {  /* MacBook6,1 (Core2 Duo, October 2009) */
+    .type = MACHINE_MACBOOK_6,
+    .lcd_backlight_probe = mbp_sysfs_backlight_probe,
+    .lcd_backlight_step = sysfs_backlight_step,
+    .lcd_backlight_toggle = sysfs_backlight_toggle,
+    /* .evdev_identify = evdev_is_wellspring3, */
+  },
+
   /* MacBook Air machines */
 
   {  /* MacBookAir1,1 (January 2008) */
@@ -345,6 +370,14 @@ struct machine_ops mb_mops[] = {
     .lcd_backlight_step = sysfs_backlight_step,
     .lcd_backlight_toggle = sysfs_backlight_toggle,
     /* .evdev_identify = evdev_is_wellspring3, */
+  },
+
+  {  /* MacBookAir3,1 & 3,2 (October 2010) */
+    .type = MACHINE_MACBOOKAIR_3,
+    .lcd_backlight_probe = mbp_sysfs_backlight_probe,
+    .lcd_backlight_step = sysfs_backlight_step,
+    .lcd_backlight_toggle = sysfs_backlight_toggle,
+    /* .evdev_identify = evdev_is_wellspring4a / evdev_is_wellspring4, */
   }
 };
 #endif /* __powerpc__ */
@@ -438,6 +471,12 @@ kbd_set_fnmode(void)
       return;
     }
 
+  if (!fp)
+    {
+      logmsg(LOG_INFO, "Could not set fnmode: no sysfs node found!");
+      return;
+    }
+
   fprintf(fp, "%d", general_cfg.fnmode);
 
   fclose(fp);
@@ -683,6 +722,13 @@ check_machine_dmi(void)
 	   || (strcmp(buf, "MacBookPro5,4") == 0)
 	   || (strcmp(buf, "MacBookPro5,5") == 0))
     ret = MACHINE_MACBOOKPRO_5;
+  /* Core i5/i7 MacBook Pro 15" & 17" (April 2010) */
+  else if ((strcmp(buf, "MacBookPro6,1") == 0)
+	   || (strcmp(buf, "MacBookPro6,2") == 0))
+    ret = MACHINE_MACBOOKPRO_6;
+  /* Core2 Duo MacBook Pro 13" (April 2010) */
+  else if (strcmp(buf, "MacBookPro7,1") == 0)
+    ret = MACHINE_MACBOOKPRO_7;
   /* Core Duo MacBook (May 2006) */
   else if (strcmp(buf, "MacBook1,1") == 0)
     ret = MACHINE_MACBOOK_1;
@@ -698,12 +744,18 @@ check_machine_dmi(void)
   /* Core2 Duo MacBook (October 2008) (5,2 white MacBook) */
   else if ((strcmp(buf, "MacBook5,1") == 0) || (strcmp(buf, "MacBook5,2") == 0))
     ret = MACHINE_MACBOOK_5;
+  /* Core2 Duo MacBook (October 2009) */
+  else if (strcmp(buf, "MacBook6,1") == 0)
+    ret = MACHINE_MACBOOK_6;
   /* MacBook Air (January 2008) */
   else if (strcmp(buf, "MacBookAir1,1") == 0)
     ret = MACHINE_MACBOOKAIR_1;
   /* MacBook Air (October 2008) */
   else if (strcmp(buf, "MacBookAir2,1") == 0)
     ret = MACHINE_MACBOOKAIR_2;
+  /* MacBook Air 11" & 13" (October 2010) */
+  else if ((strcmp(buf, "MacBookAir3,1") == 0) || (strcmp(buf, "MacBookAir3,2") == 0))
+    ret = MACHINE_MACBOOKAIR_3;
   else
     logmsg(LOG_ERR, "Unknown Apple machine: %s", buf);
 
@@ -719,7 +771,7 @@ static void
 usage(void)
 {
   printf("pommed v" M_VERSION " Apple laptops hotkeys handler\n");
-  printf("Copyright (C) 2006-2009 Julien BLACHE <jb@jblache.org>\n");
+  printf("Copyright (C) 2006-2010 Julien BLACHE <jb@jblache.org>\n");
 
   printf("Usage:\n");
   printf("\tpommed\t-- start pommed as a daemon\n");
@@ -761,7 +813,7 @@ main (int argc, char **argv)
 
 	  case 'v':
 	    printf("pommed v" M_VERSION " Apple laptops hotkeys handler\n");
-	    printf("Copyright (C) 2006-2009 Julien BLACHE <jb@jblache.org>\n");
+	    printf("Copyright (C) 2006-2010 Julien BLACHE <jb@jblache.org>\n");
 
 	    exit(0);
 	    break;
@@ -787,7 +839,7 @@ main (int argc, char **argv)
     }
 
   logmsg(LOG_INFO, "pommed v" M_VERSION " Apple laptops hotkeys handler");
-  logmsg(LOG_INFO, "Copyright (C) 2006-2009 Julien BLACHE <jb@jblache.org>");
+  logmsg(LOG_INFO, "Copyright (C) 2006-2010 Julien BLACHE <jb@jblache.org>");
 
   /* Load our configuration */
   ret = config_load();
