@@ -43,6 +43,7 @@ enum {
   SYSFS_DRIVER_RIVA,
 #else
   SYSFS_DRIVER_MBP,
+  SYSFS_DRIVER_NOUVEAU,
   SYSFS_DRIVER_NVIDIA,
 #endif
 };
@@ -62,6 +63,7 @@ static char *actual_brightness[] =
     "/sys/class/backlight/rivabl0/actual_brightness",
 #else
     "/sys/class/backlight/mbp_backlight/actual_brightness",
+    "/sys/class/backlight/nv_backlight/actual_brightness",
     "/sys/class/backlight/nvidia_backlight/actual_brightness",
 #endif
   };
@@ -77,6 +79,7 @@ static char *brightness[] =
     "/sys/class/backlight/rivabl0/brightness",
 #else
     "/sys/class/backlight/mbp_backlight/brightness",
+    "/sys/class/backlight/nv_backlight/brightness",
     "/sys/class/backlight/nvidia_backlight/brightness",
 #endif
   };
@@ -92,6 +95,7 @@ static char *max_brightness[] =
     "/sys/class/backlight/rivabl0/max_brightness",
 #else
     "/sys/class/backlight/mbp_backlight/max_brightness",
+    "/sys/class/backlight/nv_backlight/max_brightness",
     "/sys/class/backlight/nvidia_backlight/max_brightness",
 #endif
   };
@@ -403,6 +407,11 @@ mbp_sysfs_backlight_probe(void)
 
   ret = sysfs_backlight_probe(SYSFS_DRIVER_MBP);
 
+  if (ret == 0)
+    return 0;
+
+  ret = sysfs_backlight_probe(SYSFS_DRIVER_NOUVEAU);
+
   if (ret == 0)
     return 0;
 
@@ -417,8 +426,11 @@ mbp_sysfs_backlight_probe(void)
       case MACHINE_MACBOOKPRO_3:
       case MACHINE_MACBOOKPRO_4:
       case MACHINE_MACBOOKPRO_5:
+      case MACHINE_MACBOOKPRO_6:
       case MACHINE_MACBOOK_5:
+      case MACHINE_MACBOOK_6:
       case MACHINE_MACBOOKAIR_2:
+      case MACHINE_MACBOOKAIR_3:
 	logmsg(LOG_INFO, "sysfs backlight probe failed, falling back to nv8600mgt");
 
 	ret = nv8600mgt_backlight_probe();
